@@ -22,12 +22,11 @@
  *   with this program; if not, write to the Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- *   $Id: web.c 288 2008-06-17 13:22:02Z rd235 $
+ *   $Id$
  *
  */
 #include <config.h>
 #include  <stdio.h>
-#define __USE_GNU
 #include  <signal.h>
 #include <stdarg.h>
 #include <syslog.h>
@@ -64,7 +63,7 @@ struct webstat {
 	unsigned int bodylen;
 	char linebuf[BUFSIZE];
 	char path[BUFSIZE];
-	int  bufindex;
+	unsigned int  bufindex;
 };
 
 static void lowercase(char *s)
@@ -105,10 +104,11 @@ void encode64(const char *from, char *to, int tosize) {
 }
 
 void decode64(const char *src, char *dest, int dest_size) {
+	(void) dest_size;
 
 	int convbuf;
 	int l = strlen(src);
-	char c_src[l];
+	char c_src[l + 1];
 	char *c;
 
 	int i, j;
@@ -169,6 +169,8 @@ static int vde_getanswer(voidfun f,void *arg,int vdefd)
 	int n=0,ib=0,il=0,indata=0,eoa=0;
 	do {
 		n=read(vdefd,buf,BUFSIZE);
+		if (n==0)
+			exit(0);
 		for(ib=0;ib<n;ib++)
 		{
 			linebuf[il++]=buf[ib];
@@ -267,6 +269,7 @@ static void vde_addmenu(struct vdemenu **headp,char *name,char *help)
 
 static void vde_helpline(struct vdemenu **headp,char *buf,int len,int indata,int rv)
 {
+	(void) rv;
 	static int nl=0;
 	static int syntaxpos,helppos;
 	nl++;
@@ -312,14 +315,17 @@ static void vde_helpline(struct vdemenu **headp,char *buf,int len,int indata,int
 
 static struct vdemenu *vde_gethelp(int vdefd)
 {
+	ssize_t voidn;
+	(void) voidn;
 	struct vdemenu *head=NULL;
-	write(vdefd,"help\n",5);
+	voidn = write(vdefd,"help\n",5);
 	vde_getanswer(vde_helpline,&head,vdefd);
 	return head;
 }
 
 static void lwip_showline(int *fdp,char *buf,int len,int indata,int rv)
 {
+	(void) rv;
 	if (indata)
 		lwip_write(*fdp,buf,len);
 }
@@ -356,7 +362,7 @@ static char *uriconv(char *in)
 
 static void postdata_parse(int fd,int vdefd,char *menu,char *postdata)
 {
-	char cmdbuf[BUFSIZE];
+	char cmdbuf[BUFSIZE+1];
 	int cmdlen,arglen,rv;
 	char *postcmd,*cmd,*endcmd,*arg=NULL;
 	/*printf("PD **%s**\n",postdata);*/
@@ -382,12 +388,14 @@ static void postdata_parse(int fd,int vdefd,char *menu,char *postdata)
 			}
 		}
 		if(cmd!=NULL && *cmd != 0) {
+			ssize_t voidn;
+			(void) voidn;
 			strncpy(cmdbuf,menu,BUFSIZE);
 			strncat(cmdbuf,"/",BUFSIZE);
 			strncat(cmdbuf,cmd,BUFSIZE);
 			strncat(cmdbuf," ",BUFSIZE);
 			strncat(cmdbuf,uriconv(arg),BUFSIZE);
-			write(vdefd,cmdbuf,strlen(cmdbuf));
+			voidn = write(vdefd,cmdbuf,strlen(cmdbuf));
 			lwip_printf(fd,"<P> </P><B>%s %s</B><PRE>",prompt,cmdbuf);
 			rv=lwip_showout(fd,vdefd);
 			lwip_printf(fd,"</PRE><B>Result: %s</B>\r\n",strerror(rv-1000));
@@ -395,6 +403,8 @@ static void postdata_parse(int fd,int vdefd,char *menu,char *postdata)
 	}
 	else if ((postcmd=strstr(postdata,"COMMAND="))!=NULL) {
 		/* accept button */
+		ssize_t voidn;
+		(void) voidn;
 		postcmd+=8;
 		for(cmdlen=0;postcmd[cmdlen] != '&' && postcmd[cmdlen] != 0; cmdlen++)
 			;
@@ -416,7 +426,7 @@ static void postdata_parse(int fd,int vdefd,char *menu,char *postdata)
 			}
 		} else
 			*endcmd=0;
-		write(vdefd,cmdbuf,strlen(cmdbuf));
+		voidn = write(vdefd,cmdbuf,strlen(cmdbuf));
 		lwip_printf(fd,"<P> </P><B>%s %s</B><PRE>",prompt,cmdbuf);
 		rv=lwip_showout(fd,vdefd);
 		lwip_printf(fd,"</PRE><B>Result: %s</B>\r\n",strerror(rv-1000));
@@ -495,15 +505,17 @@ static void web_create_page(char *path,int fd,int vdefd,char *postdata)
 {
 	struct vdemenu *this=NULL;
 	char *tail;
+	ssize_t voidn;
+	(void) voidn;
 	if ((tail=strstr(path,".html")) != NULL)
 		*tail=0;
 	if (*path==0 || ((this=vde_findmenu(menuhead,path)) != NULL)) {
-		lwip_write(fd,okmsg,sizeof(okmsg));
+		lwip_write(fd,okmsg,sizeof(okmsg)-1);
 		lwip_printf(fd,
 				"<HTML><HEAD>\r\n"
 				"<TITLE>%s %s</TITLE>\r\n",
 				prompt, (*path==0)?"Home Page":path);
-		lwip_write(fd,css,sizeof(css));
+		lwip_write(fd,css,sizeof(css)-1);
 		lwip_printf(fd,
 				"</HEAD><BODY class=core>\r\n"
 				"<H1>%s %s</H1>\r\n"
@@ -512,7 +524,7 @@ static void web_create_page(char *path,int fd,int vdefd,char *postdata)
 		web_menu_index(fd);
 		if (*path==0) {/* HOME PAGE */
 			int rv;
-			write(vdefd,"showinfo\r\n",10);
+			voidn = write(vdefd,"showinfo\r\n",10);
 			lwip_printf(fd,
 					"</TD><TD><PRE>\r\n");
 			rv=lwip_showout(fd,vdefd);
@@ -536,7 +548,7 @@ static void web_create_page(char *path,int fd,int vdefd,char *postdata)
 				"<hr>VDE 2.0 WEB MGMT INTERFACE\r\n"
 				"</BODY></HTML>\r\n");
 	} else
-		lwip_write(fd,errmsg,sizeof(errmsg));
+		lwip_write(fd,errmsg,sizeof(errmsg)-1);
 }
 
 static char authmsg[]= 
@@ -600,9 +612,9 @@ int web_core(int fn,int fd,int vdefd)
 	} else if (st->linebuf[0]=='\n' || st->linebuf[0]=='\r') {
 		switch (st->status) {
 			case WEB_IDENTIFY:
-				lwip_write(fd,authmsg,sizeof(authmsg));
+				lwip_write(fd,authmsg,sizeof(authmsg)-1);
 				lwip_write(fd,prompt,strlen(prompt));
-				lwip_write(fd,authmsg2,sizeof(authmsg2));
+				lwip_write(fd,authmsg2,sizeof(authmsg2)-1);
 				return 1;
 				break;
 			case WEB_AUTHORIZED:
@@ -651,6 +663,8 @@ void webdata(int fn,int fd,int vdefd)
 
 void webaccept(int fn,int fd,int vdefd)
 {
+	(void) fn;
+	(void) vdefd;
 	struct sockaddr_in  cli_addr;
 	int newsockfd;
 	unsigned int clilen;
